==> img0ch-2.1.11.zip: img0ch/_template/default/index.cs <==
<html>
<head>
<title><?cs var:html_escape(BBS_TITLE) ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript">
//<!--
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
function redir(element) {
    app.redirectRenderer(element);
    return true;
}
//-->
</script>
<style type="text/css">
<!--
.clear { clear: both; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; margin-right: 4px; margin-bottom: 1px; }
-->
</style>
<?cs var:META ?>
</head>

<body bgcolor="<?cs var:html_escape(BBS_BG_COLOR) ?>" text="<?cs var:html_escape(BBS_TEXT_COLOR) ?>" link="<?cs var:html_escape(BBS_LINK_COLOR) ?>" alink="<?cs var:html_escape(BBS_ALINK_COLOR) ?>" vlink="<?cs var:html_escape(BBS_VLINK_COLOR) ?>" background="<?cs var:html_escape(BBS_BG_PICTURE) ?>">

<center>
<a name="top" />
<?cs if:BBS_TITLE_PICTURE ?><?cs if:BBS_TITLE_LINK ?><a href="<?cs var:html_escape(BBS_TITLE_LINK) ?>"><img src="<?cs var:html_escape(BBS_TITLE_PICTURE) ?>" border="0" /></a><?cs else ?><img src="<?cs var:html_escape(BBS_TITLE_PICTURE) ?>" border="0" /><?cs /if ?>
<?cs /if ?>

<a name="info" />
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">
 <tr>
  <td>
   <table border="0" width="100%">
    <tr>
     <td>
      <b><big><?cs var:html_escape(BBS_SUBTITLE) ?></big></b>
     </td>
     <td align="right">
      <a href="#menu"></a> <a href=#1></a>
     </td>
    </tr>
    <tr>
     <td colspan="2">
      <?cs var:HEAD ?>
     </td>
    </tr>
   </table>
  </td>
 </tr>
 <tr>
  <td align=center>
   <a href="../index.html" Target=_blank><small><b>fꗗ</b></small></a>
  </td>
 </tr>
</table>
<br>

<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="#ccffcc" align="center"><?cs var:Banner ?></table><br><?cs /if ?>

<a name="menu" />
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_MAKETHREAD_COLOR) ?>">
 <tr>
  <td>
   <small>
   <?cs each:item = Threads ?><a href="<?cs var:html_escape(CGIURI) ?>/<?cs var:html_escape(Renderer) ?><?cs var:html_escape(RendererSeparator) ?><?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/l50" onclick="redir(this)"><?cs var:html_escape(item.index) ?>:</a> <a href="#<?cs var:html_escape(item.index) ?>"><?cs var:item.subject ?> (<?cs var:html_escape(item.res) ?>)</a>
   <?cs /each ?>
   <?cs each:item = Stored ?><a href="<?cs var:html_escape(CGIURI) ?>/<?cs var:html_escape(Renderer) ?><?cs var:html_escape(RendererSeparator) ?><?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/l50" onclick="redir(this)"><?cs var:html_escape(item.index) ?>: <?cs var:item.subject ?> (<?cs var:html_escape(item.res) ?>)</a>
   <?cs /each ?>
   <div align="right"><b><a href="<?cs var:html_escape(BBSURI) ?>/subback.html">Xbhꗗ͂</a></b></div>
   </small>
  </td>
 </tr>
</table><br>

<?cs each:t = Threads ?>
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_THREAD_COLOR) ?>">
 <tr>
  <td>
   <dl>
   <a name="<?cs var:html_escape(t.index) ?>" />
   <div align="right"><a href="#menu"></a><a href="#<?cs var:html_escape(t.up) ?>"></a><a href="#<?cs var:html_escape(t.down) ?>"></a></div>
   <b>y<?cs var:html_escape(t.index) ?>:<?cs var:html_escape(t.res) ?>z<font size="+2" color="<?cs var:html_escape(BBS_SUBJECT_COLOR) ?>"><?cs var:t.subject ?></font></b>
   <?cs each:r = t.Thread ?><dt><?cs var:html_escape(r.resno) ?> OF<?cs if:r.mail ?><a href="mailto:<?cs var:html_escape(r.mail) ?>"><b><?cs var:r.name ?></b></a><?cs else ?><b><font color="<?cs var:html_escape(BBS_NAME_COLOR) ?>"><?cs var:r.name ?></font></b><?cs /if ?></b>F<?cs var:html_escape(r.date) ?></dt><dd><?cs var:r.text ?><br><br></dd>
   <?cs /each ?>
   <form class="comment" method="POST" action="<?cs var:html_escape(CGIURI) ?>/bbs.cgi" enctype="multipart/form-data">
   <input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
   <input type="hidden" name="key" value="<?cs var:html_escape(t.key) ?>">
   <input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>">
   <input type="submit" value="" name="submit">
 OF<input type="text" name="FROM" size="19"> E-mailF<input type="text" name="mail" size="19"><br><ul>
   <?cs if:UploadableFromRes ?>摜F<input type="file" name="file" size="74"><br><?cs /if ?>
   <?cs if:Icon ?>ACRF<select name="icon"><option value="" selected>Ȃ</option>
   <?cs each:item = Icons ?><option value="<?cs var:item.id ?>"><?cs var:item.name ?></option>
   <?cs /each ?></select><br><?cs /if ?>
 <textarea rows="5" cols="64" wrap="off" name="MESSAGE"></textarea><br>
 <?cs if:UploadableFromRes ?>폜pXF<input type="password" name="pass"><br><?cs /if ?>
<b><a href="<?cs var:html_escape(CGIURI) ?>/<?cs var:html_escape(Renderer) ?><?cs var:html_escape(RendererSeparator) ?><?cs var:html_escape(BBS) ?>/<?cs var:html_escape(t.key) ?>/" onclick="redir(this)">Sǂ</a>
<a href="<?cs var:html_escape(CGIURI) ?>/<?cs var:html_escape(Renderer) ?><?cs var:html_escape(RendererSeparator) ?><?cs var:html_escape(BBS) ?>/<?cs var:html_escape(t.key) ?>/l50" onclick="redir(this)">ŐV50</a>
<a href="<?cs var:html_escape(CGIURI) ?>/<?cs var:html_escape(Renderer) ?><?cs var:html_escape(RendererSeparator) ?><?cs var:html_escape(BBS) ?>/<?cs var:html_escape(t.key) ?>/1-100" onclick="redir(this)">1-100</a>
<?cs if:Uploadable ?><a href="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(t.key) ?>/">t@CǗ</a><?cs /if  ?>
<a href="#top">̃gbv</a> <a href="./index.html">[h</a>
   </ul>
   </form>
   </dl>
  </td>
 </tr>
</table><br>
<?cs /each ?>

<form class="comment" method="POST" action="<?cs var:html_escape(CGIURI) ?>/bbs.cgi" enctype="multipart/form-data">
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_MAKETHREAD_COLOR) ?>">
 <tr>
  <td>
   <b>XbhVK쐬</b><br>
<?cs if:BBS_PASSWORD_CHECK ?>
   <input type="submit" value=" VKXbh쐬ʂ "><br>
   <input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
   <input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>">
   <input type="hidden" name="FROM" value="">
   <input type="hidden" name="mail" value="">
<?cs else ?>
   <center>
   <input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
   <input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>">
   <table border=0>
    <tr>
     <td>
      ^CgF<input type="text" name="subject" size=25>@<input type="submit" value="VKXbh쐬"><br>
      O<font size=1>iȗj</font>F<input type="text" name="FROM" size=19 value="">
      E-mail<font size=1>iȗj</font>F<input type="text" name="mail" size=19 value=""><br>
      <?cs if:UploadableFromThread ?><input type="file" name="file" size="80"><br><?cs /if ?>
      <textarea rows=5 cols=64 wrap=off name="MESSAGE"></textarea>
      <?cs if:UploadableFromThread ?><br>폜pXF<input type="password" name="pass"><?cs /if ?>
     </td>
    </tr>
   </table>
   </center>
   <?cs var:html_escape(VERSION) ?>
<?cs /if ?>
  </td>
 </tr>
</table>
</form>
<?cs var:FOOT ?>
</center>
</body>
</html>

==> img0ch-2.1.16.zip: img0ch/_template/default/index.cs <==
<html>
<head>
<title><?cs var:html_escape(BBS_TITLE) ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript">
//<!--
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
function redir(element) {
    app.redirectRenderer(element);
    return true;
}
//-->
</script>
<style type="text/css">
<!--
.clear { clear: both; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; margin-right: 4px; margin-bottom: 1px; }
-->
</style>
<?cs var:META ?>
</head>

<body bgcolor="<?cs var:html_escape(BBS_BG_COLOR) ?>" text="<?cs var:html_escape(BBS_TEXT_COLOR) ?>" link="<?cs var:html_escape(BBS_LINK_COLOR) ?>" alink="<?cs var:html_escape(BBS_ALINK_COLOR) ?>" vlink="<?cs var:html_escape(BBS_VLINK_COLOR) ?>" background="<?cs var:html_escape(BBS_BG_PICTURE) ?>">

<center>
<a name="top" />
<?cs if:BBS_TITLE_PICTURE ?><?cs if:BBS_TITLE_LINK ?><a href="<?cs var:html_escape(BBS_TITLE_LINK) ?>"><img src="<?cs var:html_escape(BBS_TITLE_PICTURE) ?>" border="0" /></a><?cs else ?><img src="<?cs var:html_escape(BBS_TITLE_PICTURE) ?>" border="0" /><?cs /if ?>
<?cs /if ?>

<a name="info" />
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">
 <tr>
  <td>
   <table border="0" width="100%">
    <tr>
     <td>
      <b><big><?cs var:html_escape(BBS_SUBTITLE) ?></big></b>
     </td>
     <td align="right">
      <a href="#menu"></a> <a href=#1></a>
     </td>
    </tr>
    <tr>
     <td colspan="2">
      <?cs var:HEAD ?>
     </td>
    </tr>
   </table>
  </td>
 </tr>
 <tr>
  <td align=center>
   <a href="../index.html" Target=_blank><small><b>fꗗ</b></small></a>
  </td>
 </tr>
</table>
<br>

<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="#ccffcc" align="center"><?cs var:Banner ?></table><br><?cs /if ?>

<a name="menu" />
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_MAKETHREAD_COLOR) ?>">
 <tr>
  <td>
   <small>
   <?cs each:item = Threads ?><a href="<?cs var:html_escape(CGIURI) ?>/<?cs var:html_escape(Renderer) ?><?cs var:html_escape(RendererSeparator) ?><?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/l50" onclick="redir(this)"><?cs var:html_escape(item.index) ?>:</a> <a href="#<?cs var:html_escape(item.index) ?>"><?cs var:item.subject ?> (<?cs var:html_escape(item.res) ?>)</a>
   <?cs /each ?>
   <?cs each:item = Stored ?><a href="<?cs var:html_escape(CGIURI) ?>/<?cs var:html_escape(Renderer) ?><?cs var:html_escape(RendererSeparator) ?><?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/l50" onclick="redir(this)"><?cs var:html_escape(item.index) ?>: <?cs var:item.subject ?> (<?cs var:html_escape(item.res) ?>)</a>
   <?cs /each ?>
   <div align="right"><b><a href="<?cs var:html_escape(BBSURI) ?>/subback.html">Xbhꗗ͂</a></b></div>
   </small>
  </td>
 </tr>
</table><br>

<?cs each:t = Threads ?>
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_THREAD_COLOR) ?>">
 <tr>
  <td>
   <dl>
   <a name="<?cs var:html_escape(t.index) ?>" />
   <div align="right"><a href="#menu"></a><a href="#<?cs var:html_escape(t.up) ?>"></a><a href="#<?cs var:html_escape(t.down) ?>"></a></div>
   <b>y<?cs var:html_escape(t.index) ?>:<?cs var:html_escape(t.res) ?>z<font size="+2" color="<?cs var:html_escape(BBS_SUBJECT_COLOR) ?>"><?cs var:t.subject ?></font></b>
   <?cs each:r = t.Thread ?><dt><?cs var:html_escape(r.resno) ?> OF<?cs if:r.mail ?><a href="mailto:<?cs var:html_escape(r.mail) ?>"><b><?cs var:r.name ?></b></a><?cs else ?><b><font color="<?cs var:html_escape(BBS_NAME_COLOR) ?>"><?cs var:r.name ?></font></b><?cs /if ?></b>F<?cs var:html_escape(r.date) ?></dt><dd><?cs var:r.text ?><br><br></dd>
   <?cs /each ?>
   <form class="comment" method="POST" action="<?cs var:html_escape(CGIURI) ?>/bbs.cgi" enctype="multipart/form-data">
   <input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
   <input type="hidden" name="key" value="<?cs var:html_escape(t.key) ?>">
   <input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>">
   <input type="submit" value="" name="submit">
 OF<input type="text" name="FROM" size="19"> E-mailF<input type="text" name="mail" size="19"><br><ul>
   <?cs if:UploadableFromRes ?>摜F<input type="file" name="file" size="74"><br><?cs /if ?>
   <?cs if:Icon ?>ACRF<select name="icon"><option value="" selected>Ȃ</option>
<?cs each:item = Icons ?><option value="<?cs var:item.id ?>"><?cs var:item.name ?></option>
<?cs /each ?></select><br><?cs /if ?>
 <textarea rows="5" cols="64" wrap="off" name="MESSAGE"></textarea><br>
 <?cs if:UploadableFromRes ?>폜pXF<input type="password" name="pass"><br><?cs /if ?>
<b><a href="<?cs var:html_escape(CGIURI) ?>/<?cs var:html_escape(Renderer) ?><?cs var:html_escape(RendererSeparator) ?><?cs var:html_escape(BBS) ?>/<?cs var:html_escape(t.key) ?>/" onclick="redir(this)">Sǂ</a>
<a href="<?cs var:html_escape(CGIURI) ?>/<?cs var:html_escape(Renderer) ?><?cs var:html_escape(RendererSeparator) ?><?cs var:html_escape(BBS) ?>/<?cs var:html_escape(t.key) ?>/l50" onclick="redir(this)">ŐV50</a>
<a href="<?cs var:html_escape(CGIURI) ?>/<?cs var:html_escape(Renderer) ?><?cs var:html_escape(RendererSeparator) ?><?cs var:html_escape(BBS) ?>/<?cs var:html_escape(t.key) ?>/1-100" onclick="redir(this)">1-100</a>
<?cs if:Uploadable ?><a href="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(t.key) ?>/">t@CǗ</a><?cs /if  ?>
<a href="#top">̃gbv</a> <a href="./index.html">[h</a>
   </ul>
   </form>
   </dl>
  </td>
 </tr>
</table><br>
<?cs /each ?>

<form class="comment" method="POST" action="<?cs var:html_escape(CGIURI) ?>/bbs.cgi" enctype="multipart/form-data">
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_MAKETHREAD_COLOR) ?>">
 <tr>
  <td>
   <b>XbhVK쐬</b><br>
<?cs if:BBS_PASSWORD_CHECK ?>
   <input type="submit" value=" VKXbh쐬ʂ "><br>
   <input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
   <input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>">
   <input type="hidden" name="FROM" value="">
   <input type="hidden" name="mail" value="">
<?cs else ?>
   <center>
   <input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
   <input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>">
   <table border=0>
    <tr>
     <td>
      ^CgF<input type="text" name="subject" size=25>@<input type="submit" value="VKXbh쐬"><br>
      O<font size=1>iȗj</font>F<input type="text" name="FROM" size=19 value="">
      E-mail<font size=1>iȗj</font>F<input type="text" name="mail" size=19 value=""><br>
      <?cs if:UploadableFromThread ?><input type="file" name="file" size="80"><br><?cs /if ?>
      <?cs if:Icon ?>ACRF<select name="icon"><option value="" selected>Ȃ</option>
      <?cs each:item = Icons ?><option value="<?cs var:item.id ?>"><?cs var:item.name ?></option>
      <?cs /each ?></select><br><?cs /if ?>
      <textarea rows=5 cols=64 wrap=off name="MESSAGE"></textarea>
      <?cs if:UploadableFromThread ?><br>폜pXF<input type="password" name="pass"><?cs /if ?>
     </td>
    </tr>
   </table>
   </center>
   <?cs var:html_escape(VERSION) ?>
<?cs /if ?>
  </td>
 </tr>
</table>
</form>
<?cs var:FOOT ?>
</center>
</body>
</html>
